<?php
/*
* Woocommerce eShipper shipping related works are here
*/
if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))))
	{
	function eShipper_init()
		{
		if (!class_exists('WC_eShipper'))
			{
			class WC_eShipper extends WC_Shipping_Method
				{
				/**
				 * Constructor for your shipping class
				 *
				 * @access public
				 * @return void
				 */
				public function __construct()
					{
					$this->id = 'WC_eShipper'; // Id for your shipping method. Should be uunique.
					$this->method_title = __('eShipper', 'WC_eShipper'); // Title shown in admin
					$this->method_description = __('eShipper', 'WC_eShipper'); // Description shown in admin
					$this->init();
					}
				/**
				 * Init function
				 *
				 * @access public
				 * @return void
				 */
				function init()
					{
					$default_options = (object)array(
						'enabled' => 'no',
						'title' => 'eShipper',
						'api_url' => 'https://web.eshipper.com/rpc2',
						'api_user' => '',
						'api_pass' => '',
						'source_postalcode' => '',
						'source_country' => '',
						'source_province' => '',
						'source_city' => '',
						'source_name' => '',
						'source_address1' => '',
						'source_address2' => '',
						'source_address3' => '',
						'source_phone' => '',
						'source_fax' => '',
						'source_address_type' => '',
						'source_company_name' => '',
						'increase_rate' => 0
					);
					$this->options = get_option('woocommerce_eShipper', $default_options);
					$this->enabled = $this->options->enabled;
					$this->title = $this->options->title;
					// Save settings in admin if you have any defined
					add_action('woocommerce_update_options_shipping_' . $this->id, array(
						$this,
						'process_admin_options'
					));
					}
				/**
				 * calculate_shipping function.
				 *
				 * @access public
				 * @param mixed $package
				 * @return void
				 */
				public function calculate_shipping($packages = array())
					{
					$this->shipping_total = 0;
					$this->shipping_taxes = array();
					$this->packages = array();
					if (!function_exists('xml2js'))
						{
						function xml2js($xmlnode)
							{
							$root = (func_num_args() > 1 ? false : true);
							$jsnode = array();
							if (!$root)
								{
								if (count($xmlnode->attributes()) > 0)
									{
									$jsnode["$"] = array();
									foreach($xmlnode->attributes() as $key => $value) $jsnode["$"][$key] = (string)$value;
									}
								$textcontent = trim((string)$xmlnode);
								if (count($textcontent) > 0) $jsnode["<br />"] = $textcontent;
								foreach($xmlnode->children() as $childxmlnode)
									{
									$childname = $childxmlnode->getName();
									if (!array_key_exists($childname, $jsnode)) $jsnode[$childname] = array();
									array_push($jsnode[$childname], xml2js($childxmlnode, true));
									}
								return $jsnode;
								}
							  else
								{
								$nodename = $xmlnode->getName();
								$jsnode[$nodename] = array();
								array_push($jsnode[$nodename], xml2js($xmlnode, true));
								return json_encode($jsnode);
								}
							}
						}
					global $woocommerce;
					// currency
					$eShipper_currency = get_option('woocommerce_currency');
					$woocommerce_eShipper_settings = (array)get_option("woocommerce_eShipper");					// origin details

					$eShipper_origin_country = $woocommerce_eShipper_settings['source_country'];
					$eShipper_origin_postal_code = $woocommerce_eShipper_settings['source_postalcode'];
					$eShipper_origin_province = $woocommerce_eShipper_settings['source_province'];
					$eShipper_origin_city = $woocommerce_eShipper_settings['source_city'];
					$eShipper_origin_name = $woocommerce_eShipper_settings['source_name'];
					$eShipper_origin_address1 = $woocommerce_eShipper_settings['source_address1'];
					$eShipper_origin_address2 = $woocommerce_eShipper_settings['source_address2'];
					$eShipper_origin_address3 = $woocommerce_eShipper_settings['source_address3'];
					$eShipper_origin_phone = $woocommerce_eShipper_settings['source_phone'];
					$eShipper_origin_fax = $woocommerce_eShipper_settings['source_fax'];
					$eShipper_origin_address_type = $woocommerce_eShipper_settings['source_address_type'];
					$eShipper_origin_company_name = $woocommerce_eShipper_settings['source_company_name'];

					// api settings

					$api_username = $woocommerce_eShipper_settings['api_user'];
					$api_password = $woocommerce_eShipper_settings['api_pass'];
					$api_url = $woocommerce_eShipper_settings['api_url'];

					// destination details

					$user_id = get_current_user_id();
					$woocusobj = $woocommerce->customer;
					$eShipper_destintn_country = $woocusobj->get_shipping_country();
					$eShipper_destintn_postal_code = $woocusobj->get_shipping_postcode();
					$eShipper_destintn_province = $woocusobj->get_shipping_state();
					$eShipper_destintn_city = $woocusobj->get_shipping_city();
					$eShipper_destintn_name = get_user_meta($user_id, 'shipping_first_name', true);
					$eShipper_destintn_address1 = $woocusobj->get_shipping_address();
					$eShipper_destintn_address2 = $woocusobj->get_shipping_address_2();
					$eShipper_destintn_address3 = "";
					$eShipper_destintn_phone = "";
					$eShipper_destintn_fax = "";
					$eShipper_destintn_address_type = "";
					$eShipper_destintn_company_name = get_user_meta($user_id, 'shipping_company', true);
					$item_string = "";
					$total_item_weight = 0;
					$items = $woocommerce->cart->get_cart();

					// xml_data

					$xml = new SimpleXMLElement('<EShipper></EShipper>');
					$xml->addAttribute('xmlns', $api_url);
					$xml->addAttribute('username', $api_username);
					$xml->addAttribute('password', $api_password);
					$xml->addAttribute('version', '3.0.0');
					$qrequest = $xml->addChild('QuoteRequest');
					$qrequest->addAttribute('serviceId', '0');
					$qrequest->addAttribute('stackable', 'true');
					$from = $qrequest->addChild("From");
					$from->addAttribute('id', '1');
					$from->addAttribute('company', $eShipper_origin_name);
					$from->addAttribute('address1', $eShipper_origin_address1);
					$from->addAttribute('city', $eShipper_origin_city);
					$from->addAttribute('state', $eShipper_origin_province);
					$from->addAttribute('country', 'CA');
					$from->addAttribute('zip', $eShipper_origin_postal_code);
					$to = $qrequest->addChild("To");
					$to->addAttribute('company', $eShipper_destintn_company_name);
					$to->addAttribute('address1', $eShipper_destintn_address1);
					$to->addAttribute('city', $eShipper_destintn_city);
					$to->addAttribute('state', $eShipper_destintn_province);
					$to->addAttribute('zip', $eShipper_destintn_postal_code);
					$to->addAttribute('country', $eShipper_destintn_country);
					$cod = $qrequest->addChild("COD");
					$cod->addAttribute('paymentType', 'Check');
					$codr = $cod->addChild("CODReturnAddress");
					$codr->addAttribute('codCompany', $eShipper_destintn_company_name);
					$codr->addAttribute('codName', $eShipper_destintn_name);
					$codr->addAttribute('codPhone', '888-888-8888');
					$codr->addAttribute('codAddress1', $eShipper_destintn_address1);
					$codr->addAttribute('codAddress2', $eShipper_destintn_address1);
					$codr->addAttribute('codCity', $eShipper_destintn_city);
					$codr->addAttribute('codStateCode', $eShipper_destintn_province);
					$codr->addAttribute('codZip', $eShipper_destintn_postal_code);
					$codr->addAttribute('codCountry', 'CA');
					$package = $qrequest->addChild("Packages");
					$package->addAttribute('type', 'Package');

					// $packages as $package_key => $package

					foreach($packages['contents'] as $item_id => $values)
						{

						// $_product =  wc_get_product( $values['data']->get_id());

						$_product = $values['data'];
						$productmeta = new WC_Product($values['product_id']);
						$item_name = $_product->get_name();
						$item_sku = $_product->get_sku();
						$item_quantity = $values['quantity'];
						$item_width = $_product->get_width();
						$item_height = $_product->get_height();
						$item_length = $_product->get_length();
						$item_weight = $_product->get_weight();
						$total_item_weight+= (int)($item_weight * $item_quantity);
						$item_weightUnit = get_option('woocommerce_weight_unit');
						$item_price = $_product->get_price();
						$item_vendor = "rizeShipper";
						$item_requires_shipping = 'true';
						$item_taxable = 'true';
						$item_fulfillment_service = "manual";
						$item_product_id = $values['product_id'];
						$item_variant_id = $values['variation_id'];
						if ($item_sku == '')
							{
							$item_sku = '12345';
							}

						if ($item_weight == '')
							{
							$item_weight = '1';
							}

						if ($item_variant_id == '')
							{
							$item_variant_id = '616173013';
							}

						$packages = $package->addChild("Package");
						$packages->addAttribute('length', $item_length);
						$packages->addAttribute('width', $item_width);
						$packages->addAttribute('height', $item_height);
						$packages->addAttribute('weight', $total_item_weight);
						$packages->addAttribute('type', 'Pallet');
						$packages->addAttribute('freightClass', '70');
						$packages->addAttribute('nmfcCode', '123456');
						$packages->addAttribute('insuranceAmount', '0.0');
						$packages->addAttribute('codAmount', '0.0');
						$packages->addAttribute('description', 'desc');
						}

					// continue xml data

					$pickup = $qrequest->addChild("Pickup");
					$pickup->addAttribute('contactName', $eShipper_origin_name);
					$pickup->addAttribute('phoneNumber', '888-888-8888');
					$pickup->addAttribute('pickupDate', '2009-08-03');
					$pickup->addAttribute('pickupTime', '16:30');
					$pickup->addAttribute('closingTime', '17:45');
					$pickup->addAttribute('location', 'Front Door');

					// endxml

					$xmldata = $xml->asXML();

					// echo 'xml:'.$xmldata;
					// die();

					$url = $api_url;
					$increase_rate = $woocommerce_eShipper_settings['increase_rate'];
					$increase_rate = (float)$increase_rate;
					$ch = curl_init();
					curl_setopt($ch, CURLOPT_URL, $url);
					curl_setopt($ch, CURLOPT_POST, true);
					curl_setopt($ch, CURLOPT_HTTPHEADER, array(
						'Content-Type: appplication/xml'
					));
					curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
					curl_setopt($ch, CURLOPT_POSTFIELDS, $xmldata);
					$result = curl_exec($ch);

					// echo curl_error($ch);

					curl_close($ch);
					if (!$result || strlen(trim($result)) == 2)
						{
						$rate = array();
						$this->add_rate($rate);
						}
					  else
						{
						$xml = simplexml_load_string($result);
						$arr_data = json_decode(xml2js($xml) , true);
						$array = (array)$arr_data;
						$arr = $array['EShipper'];
						/*echo "<pre>";
						var_dump($arr);
						echo "</pre>";*/
						
						foreach($arr as $x => $val)
							{
							foreach($val as $y => $value)
								{
								if (is_array($value))
									{
									foreach($value as $z => $key1)
										{
										if (is_array($key1))
											{
											foreach($key1 as $k1 => $key2)
												{
												if (is_array($key2))
													{
													foreach($key2 as $k2 => $key3)
														{
														if (is_array($key3) && isset($key3['$']['deliveryDate']))
															{
															$max_delivery_date = "";
															if (!empty($key3['$']['deliveryDate']))
																{
																$expected_day = $key3['$']['transitDays'] + 2;
																$max_delivery_date = " (Estimated Delivery : " . $key3['$']['transitDays'] . "-" . $expected_day . " days) ";
																}
															  else
																{
																$max_delivery_date = "";
																}

															$np_label_shipping = $key3['$']['carrierName'] . " - " . $key3['$']['serviceName'] . $max_delivery_date;
															$price = $key3['$']['totalCharge'];
															$rate = array(
																'id' => "eShipper_" . $key3['$']['serviceId'],
																'label' => $np_label_shipping,
																'cost' => $price + ($price * $increase_rate * 0.01) ,
																'calc_tax' => 'per_order'
															);
															$this->add_rate($rate);
															}
														 
														}
													}
												}
											}
										}
									}
								}
							}
						}
					}

				function sort_rates($a, $b)
					{
					if ($a->cost == $b->cost)
						{
						return 0;
						}

					return ($a->cost < $b->cost) ? -1 : 1;
					}

				function admin_options()
					{
					global $woocommerce;
					wp_nonce_field(plugin_basename(__FILE__) , 'eShipper_options_noncename');					?>
<div class="notice notice-success">
       <p><b>*Note:</b> You must add weight, height, length and width to your products to get Shipping rates from EShipper. For instructions Here is the link: <a href="<?php
					get_home_url(); ?>/wp-content/plugins/woocommerce-eShipper/instructions/index.html" target="_blank">Instruction</a></p>
    </div>
                    <h3><?php
					_e('eShipper', 'woocommerce-eShipper'); ?></h3>
                    <table class="form-table wooeShipper">
                        <tr valign="top">
                            <th scope="row" class="titledesc"><?php
					_e('Enable/Disable', 'woocommerce-eShipper') ?></th>
                            <td class="forminp">
                                <fieldset>
                                    <legend class="screen-reader-text"><span><?php
					_e('Enable/Disable', 'woocommerce-eShipper') ?></span></legend>
                                    <label for="woocommerce_eShipper_enabled">
                                        <input name="woocommerce_eShipper_enabled" id="woocommerce_eShipper_enabled" type="checkbox" value="1" <?php
					checked($this->options->enabled == 'yes'); ?> />
                                        <?php
					_e('Enable eShipper Webservice', 'woocommerce-eShipper') ?>
                                    </label><br />
                                </fieldset>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row" class="titledesc"><?php
					_e('eShipper API Settings', 'woocommerce-eShipper') ?></th>
                            <td class="forminp">
                                <table class="eShipperinnetbl">
                                    <tr>
                                        <td><span class="description"><?php
					_e('API URL *', 'woocommerce-eShipper') ?></span></td>
                                        <td><input type="text" required="required" name="woocommerce_eShipper_api_url" id="woocommerce_eShipper_api_url" style="min-width:200px;" value="<?php
					echo esc_attr($this->options->api_url); ?>" /></td>
                                    </tr>
                                    <tr>
                                        <td><span class="description"><?php
					_e('Username *', 'woocommerce-eShipper') ?></span></td>
                                        <td><input type="text" required="required" name="woocommerce_eShipper_api_user" id="woocommerce_eShipper_api_user" style="min-width:200px;" value="<?php
					echo esc_attr($this->options->api_user); ?>"/></td>
                                    </tr>
                                    <tr>
                                        <td><span class="description"><?php
					_e('Password *', 'woocommerce-eShipper') ?></span></td>
                                        <td><input type="password" required="required" name="woocommerce_eShipper_api_pass" id="woocommerce_eShipper_api_pass" style="min-width:200px;" value="<?php
					echo esc_attr($this->options->api_pass); ?>"/></td>
                                    </tr>
                                </table>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th scope="row" class="titledesc"><?php
					_e('Origin Address Details', 'woocommerce-eShipper') ?></th>
                            <td class="forminp">
                                <table class="eShipperinnetbl">
                                    <tr>
                                        <td>
                                            <span class="description"><?php
					_e('Postal Code *', 'woocommerce-eShipper') ?></span>
                                            <input type="text" required="required" name="woocommerce_eShipper_source_postalcode" id="woocommerce_eShipper_source_postalcode" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_postalcode); ?>"/>
                                        </td>
                                        <td>
                                            <span class="description"><?php
					_e('Country *', 'woocommerce-eShipper') ?></span>
                                            <select required="required" name="woocommerce_eShipper_source_country" id="woocommerce_eShipper_source_country">
                                                <option value="">--Select Country--</option>
                                                <?php
					global $wpdb;
					$sql = "SELECT country_name,country_code_char2 FROM wpnp_countries";
					$all_countries = $wpdb->get_results($sql, ARRAY_A);
					foreach($all_countries as $single_country)
						{
						if (esc_attr($this->options->source_country) == $single_country['country_code_char2'])
							{
							$sltctnv = "selected='selected'";
							}
						  else
							{
							$sltctnv = "";
							}

						echo "<option value='" . $single_country['country_code_char2'] . "' " . $sltctnv . ">" . $single_country['country_name'] . "</option>";
						}

?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <span class="description"><?php
					_e('State/Province *', 'woocommerce-eShipper') ?></span>
                                            <select required="required" name="woocommerce_eShipper_source_province" id="woocommerce_eShipper_source_province">
                                                <option value="">--Select--</option>
                                            </select>
                                        </td>

                                        <td>
                                            <span class="description"><?php
					_e('Source City *', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_city" id="woocommerce_eShipper_source_city" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_city); ?>"/>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <span class="description"><?php
					_e('Shipper Name', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_name" id="woocommerce_eShipper_source_name" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_name); ?>"/>
                                        </td>
                                        <td>
                                            <span class="description"><?php
					_e('Address line 1', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_address1" id="woocommerce_eShipper_source_address1" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_address1); ?>"/>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <span class="description"><?php
					_e('Address Line 2', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_address2" id="woocommerce_eShipper_source_address2" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_address2); ?>"/>
                                        </td>
                                        <td>
                                            <span class="description"><?php
					_e('Address line 3', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_address3" id="woocommerce_eShipper_source_address3" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_address3); ?>"/></td>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <span class="description"><?php
					_e('Phone Number', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_phone" id="woocommerce_eShipper_source_phone" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_phone); ?>"/>
                                        </td>
                                        <td>
                                            <span class="description"><?php
					_e('Fax Number', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_fax" id="woocommerce_eShipper_source_fax" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_fax); ?>"/>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <span class="description"><?php
					_e('Type of address', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_address_type" id="woocommerce_eShipper_source_address_type" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_address_type); ?>"/>
                                        </td>
                                        <td>
                                            <span class="description"><?php
					_e('Company Name', 'woocommerce-eShipper') ?></span>
                                            <input type="text" name="woocommerce_eShipper_source_company_name" id="woocommerce_eShipper_source_company_name" style="min-width:50px;" value="<?php
					echo esc_attr($this->options->source_company_name); ?>"/>
                                        </td>
                                    </tr>
                                </table>
                            </td>
                        </tr>
                        <tr valign="top">
                            <th><b><?php
					_e('Increase all rates by(%)', 'woocommerce-eShipper') ?></b></th>
                            <td>
                                <input type="number" name="woocommerce_eShipper_increase_rate" id="woocommerce_eShipper_increase_rate" style="max-width:50px;" value="<?php
					echo esc_attr($this->options->increase_rate); ?>"/>
                                <span class="description"><?php
					_e('Markup option by percentage factor', 'woocommerce-eShipper') ?></span>
                            </td>
                        </tr>
                    </table>
                    <?php
					}

				function process_admin_options()
					{

					// security check

					if (!isset($_POST['eShipper_options_noncename']) || !wp_verify_nonce($_POST['eShipper_options_noncename'], plugin_basename(__FILE__)))
						{
						return;
						}

					if (isset($_POST['woocommerce_eShipper_enabled'])) $this->options->enabled = 'yes';
					  else $this->options->enabled = 'no';
					if (isset($_POST['woocommerce_eShipper_api_url'])) $this->options->api_url = wc_clean($_POST['woocommerce_eShipper_api_url']);
					if (isset($_POST['woocommerce_eShipper_api_user'])) $this->options->api_user = wc_clean($_POST['woocommerce_eShipper_api_user']);
					if (isset($_POST['woocommerce_eShipper_api_pass'])) $this->options->api_pass = wc_clean($_POST['woocommerce_eShipper_api_pass']);
					if (isset($_POST['woocommerce_eShipper_source_postalcode'])) $this->options->source_postalcode = wc_clean($_POST['woocommerce_eShipper_source_postalcode']);
					if (isset($_POST['woocommerce_eShipper_source_country'])) $this->options->source_country = wc_clean($_POST['woocommerce_eShipper_source_country']);
					if (isset($_POST['woocommerce_eShipper_source_province'])) $this->options->source_province = wc_clean($_POST['woocommerce_eShipper_source_province']);
					if (isset($_POST['woocommerce_eShipper_source_city'])) $this->options->source_city = wc_clean($_POST['woocommerce_eShipper_source_city']);
					if (isset($_POST['woocommerce_eShipper_source_name'])) $this->options->source_name = wc_clean($_POST['woocommerce_eShipper_source_name']);
					if (isset($_POST['woocommerce_eShipper_source_address1'])) $this->options->source_address1 = wc_clean($_POST['woocommerce_eShipper_source_address1']);
					if (isset($_POST['woocommerce_eShipper_source_address2'])) $this->options->source_address2 = wc_clean($_POST['woocommerce_eShipper_source_address2']);
					if (isset($_POST['woocommerce_eShipper_source_address3'])) $this->options->source_address3 = wc_clean($_POST['woocommerce_eShipper_source_address3']);
					if (isset($_POST['woocommerce_eShipper_source_phone'])) $this->options->source_phone = wc_clean($_POST['woocommerce_eShipper_source_phone']);
					if (isset($_POST['woocommerce_eShipper_source_fax'])) $this->options->source_fax = wc_clean($_POST['woocommerce_eShipper_source_fax']);
					if (isset($_POST['woocommerce_eShipper_source_address_type'])) $this->options->source_address_type = wc_clean($_POST['woocommerce_eShipper_source_address_type']);
					if (isset($_POST['woocommerce_eShipper_source_company_name'])) $this->options->source_company_name = wc_clean($_POST['woocommerce_eShipper_source_company_name']);
					if (isset($_POST['woocommerce_eShipper_increase_rate']) && is_numeric($_POST['woocommerce_eShipper_increase_rate'])) $this->options->increase_rate = wc_clean($_POST['woocommerce_eShipper_increase_rate']);
					  else $this->options->increase_rate = 0;
					if (isset($_POST['woocommerce_eShipper_max_package_size'])) $this->options->max_package_size = wc_clean($_POST['woocommerce_eShipper_max_package_size']);
					if (isset($_POST['woocommerce_eShipper_package_length'])) $this->options->package_length = wc_clean($_POST['woocommerce_eShipper_package_length']);
					if (isset($_POST['woocommerce_eShipper_package_width'])) $this->options->package_width = wc_clean($_POST['woocommerce_eShipper_package_width']);
					if (isset($_POST['woocommerce_eShipper_package_hight'])) $this->options->package_hight = wc_clean($_POST['woocommerce_eShipper_package_hight']);
					if (isset($_POST['woocommerce_eShipper_packaging'])) $this->options->packaging = 'yes';
					  else $this->options->packaging = 'no';
					if (isset($_POST['woocommerce_eShipper_packaging_type'])) $this->options->packaging_type = wc_clean($_POST['woocommerce_eShipper_packaging_type']);

					// update options

					update_option('woocommerce_eShipper', $this->options);
					}
				}
			}
		}

	add_action('woocommerce_shipping_init', 'eShipper_init');
	function add_eShipper($methods)
		{
		$methods[] = 'WC_eShipper';
		return $methods;
		}

	add_filter('woocommerce_shipping_methods', 'add_eShipper');
	}